lists of error messages for regex matching:
Search all output pages generated by fuzzing payloads for the extensive list of known error strings, for later analysis.
usage docs:
https://github.com/fuzzdb-project/fuzzdb/wiki/regexerrors

 breakpoint-ignores.txt
 List of common URLS which can be annoying while in a web proxy's breakpoint mode.
